Uses of Class org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Class
org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator

Packages that use SingleBrowserLocator
org.openqa.selenium.server.browserlaunchers.locators |

Uses of SingleBrowserLocator in org.openqa.selenium.server.browserlaunchers.locators

Subclasses of SingleBrowserLocator in org.openqa.selenium.server.browserlaunchers.locators
`class` | `Firefox2Locator` Discovers a valid Firefox 2.x installation on local system.
`class` | `Firefox3Locator` Discovers a valid Firefox 2.x or 3.x installation on local system.
`class` | `FirefoxLocator` Discovers a valid Firefox installation on local system.
`class` | `GoogleChromeLocator` Discovers a valid Google Chrome installation on local system.
`class` | `InternetExplorerLocator` Discovers a valid Internet Explorer installation on local system.
`class` | `SafariLocator` Discovers a valid Internet Explorer installation on local system.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.